"use client";

import Image from "next/image";
import Link from "next/link";
import {useEffect, useState} from "react";

import SheetMB from "../sheet-mb";
import { navbarData, navbarLink } from "@/app/data/content";

export default function Header() {
  const [scrollY, setScrollY] = useState(0);

  const handleScroll = () => {
    setScrollY(window.scrollY);
  };

  useEffect(() => {
    window.addEventListener("scroll", handleScroll);
    return () => {
      window.removeEventListener("scroll", handleScroll);
    };
  }, []);

  return (
    <header
      className={`${
        scrollY > 0
          ? "bg-main sticky "
          : "bg-main lg:bg-main/50 lg:fixed "
      } w-full  top-0 z-10 ease-in-out duration-500`}
    >
      <nav className="w-screen lg:max-w-[80%] mx-auto px-5 lg:px-0 flex justify-between items-center h-20 lg:h-28">
        <div className="flex-shrink">
          <Link href="/">
            <Image
              src='/logo-white.svg'
              alt='villa batu'
               width={180}
               height={126}
              className="object-cover w-16"
            />
          </Link>
        </div>
        <div className="hidden lg:block flex-grow">
          <ul className="flex justify-center items-center gap-[25px] tracking-wide text-lg">
            {navbarLink.map((item: any, index: number) => (
              <li
                key={index}
                className="text-sm 2xl:text-lg tracking-wide font-semibold text-white"
              >
                <Link href={item.link}>{item.title}</Link>
              </li>
            ))}
          </ul>
        </div>
        <SheetMB nav={navbarLink} socials={navbarData} className="text-white" />
      </nav>
    </header>
  );
}
